==> libstpk-0.9.1.0.tar.gz: libstpk-0.9.1.0/demo/sound_analysis/sound_1d.f90 <==
program sound_1d
! 饸ιصݴ¬ǡ, 1 Υץեǡ
! , ٤ˤѡˤ CAPE Υѥ᡼׻.
! ǥǡΥեޥåȤϥƥȷΤߥݡ

  use Thermo_Const
  use Thermo_Function
  use Thermo_Advanced_Function
  use file_operate
  use Statistics
  use Basis
  use dcl
  use Dcl_Automatic
  use Dcl_Thermo_Graph

  implicit none

  real, allocatable, dimension(:) :: temp    ! 
  real, allocatable, dimension(:) :: height  ! 
  real, allocatable, dimension(:) :: pres    ! 
  real, allocatable, dimension(:) :: rh      ! м
  real, allocatable, dimension(:) :: qv      ! 
  real, allocatable, dimension(:) :: pt      ! 
  real, allocatable, dimension(:) :: ept     ! 
  real, allocatable, dimension(:) :: sept    ! ˰
  real, allocatable, dimension(:) :: ew      ! 
  real, allocatable, dimension(:) :: ww      ! 
  real, allocatable, dimension(:) :: tmp     ! ƥݥ
  real, allocatable, dimension(:,:) :: draw_tate, draw_yoko, write_data
  real :: height_lcl, pres_lcl  ! LCL 
  real :: height_lfc, pres_lfc  ! LFC 
  real :: height_lnb, pres_lnb  ! LNB 
  real :: cape_c  ! CAPE
  real :: cin_c  ! CIN
  real :: precip  ! Ĺ߿
  real :: z_ref  ! CAPE η׻κ, .
  real :: p_ref  ! CAPE η׻κ, ൤.
  real, dimension(2) :: draw_region_p, draw_region_z
  real, dimension(6), parameter :: convx=(/0.3, 0.5, 0.55, 0.75, 0.55, 0.75/),  &
                                   convy=(/0.5, 0.8, 0.5, 0.8, 0.5, 0.8/)
  real, allocatable, dimension(:,:) :: cvx, cvy

  integer :: i, j, k, l, m, n, iz, jmax
  integer :: nz  ! 
  integer :: nnz  ! ǡޤȤ˻Ȥΰˤ
  integer :: nx  ! ǡο
  integer :: IWS
  integer, parameter :: fig_num=3  ! ޤμ

  character(80), allocatable, dimension(:,:) :: fname  ! ǡե̾
  character(80) :: list_name  ! ǡꥹȥե̾
  character(20), allocatable, dimension(:,:) :: cval  ! ǡɤ߹
  character(1000) :: tmp_char
  character(4) :: draw_flag  ! ޤ˴ؤե饰
  character(10) :: t_c
  character(20) :: skew_c
  character(10), allocatable, dimension(:) :: title_c, title_u

  logical :: dmp_flag

  real :: undef
  integer, parameter :: skip_num=2

!-- namelist file ɤ߹

  namelist /input /z_ref, p_ref, list_name, dmp_flag, undef, draw_flag,  &
  &                draw_region_p, draw_region_z, IWS
  read(5,nml=input)

  jmax=11

  allocate(title_c(jmax))
  allocate(title_u(jmax))
  allocate(cvx(jmax,fig_num))
  allocate(cvy(jmax,fig_num))

  title_c=(/'z_ref"', 'p_ref"', 'CAPE  ', 'CIN   ', 'PW    ', 'z_LCL"',  &
  &         'z_LFC"', 'z_LNB"', 'p_LCL"', 'p_LFC"', 'p_LNB"'/)
  title_u=(/'m       ', 'hPa     ', 'J kg|-1"', 'J kg|-1"',  &
  &         'mm      ', 'm       ',  &
  &         'm       ', 'm       ', 'hPa     ', 'hPa     ', 'hPa     '/)

  do i=1,fig_num
     cvx(:,i)=convx((i-1)*2+1)+0.01
     do j=1,jmax
        cvy(j,i)=convy(2*i)-0.01-(convy(2*i)-convy(2*(i-1)+1)-0.02)  &
  &              *real(j-1)/real(jmax-1)
     end do
  end do

!-- ɤ߹ǡեο
  nnz=line_number_counter( trim(list_name) )

  allocate(fname(2,nnz))
  allocate(write_data(nnz,jmax))

!-- DCL set
  call DclOpenGraphics(IWS)

  call GLRSET('RMISS',undef)
  call GLLSET('LMISS',.true.)
  call UZFACT( 0.6 )
  call DclSetParm('ENABLE_PROPORTIONAL_FONT',.true.)

  call read_file_text( trim(list_name), 2, nnz, fname )
  
  do i=1,nnz

  if(trim(fname(1,i))/='unknown')then
!-- ƥȥեɤ߹

     nz=line_number_counter( trim(fname(1,i)) )-skip_num  ! ƥȥñ̤ʬð

!-- 

     allocate(cval(6,nz))
     allocate(height(nz))
     allocate(temp(nz))
     allocate(pres(nz))
     allocate(qv(nz))
     allocate(ew(nz))
     allocate(ww(nz))
     allocate(tmp(nz))
     allocate(pt(nz))
     allocate(ept(nz))
     allocate(sept(nz))
     allocate(draw_tate(nz,3))
     allocate(draw_yoko(nz,3))

!-- ե뤫ǡɤ߹
     call read_file_text( trim(fname(1,i)), 6, nz, cval, skip=skip_num )
     write(*,*) "reading file ", trim(fname(1,i))

!-- character -> real
     do j=1,nz
        height(j)=c2r_convert( cval(1,j) )
        pres(j)=c2r_convert( cval(2,j) )
        temp(j)=c2r_convert( cval(3,j) )
        qv(j)=c2r_convert( cval(4,j) )
        ew(j)=c2r_convert( cval(5,j) )
        ww(j)=c2r_convert( cval(6,j) )
     end do

!-- z_ref  p_ref ֤
     if(z_ref==-999.0)then
        ! interpo 뤿󲽽
        do j=1,nz
           tmp(j)=pres(nz-j+1)
        end do
        call interpo_search_1d( tmp, p_ref, iz )
        call interpolation_1d( tmp(iz:iz+1), height(nz-iz+1:nz-iz),  &
  &                             p_ref, z_ref )
     end if

!-- z_ref  p_ref ֤
!  ν¿ʬʤ.
!     if(z_ref==-999.0)then
        ! interpo 뤿󲽽
!        call interpo_search_1d( height, z_ref, iz )
!        call interpolation_1d( height(iz:iz+1), pres(iz:iz+1),  &
!  &                             z_ref, p_ref )
!     end if

!-- ή԰ѥ᡼׻
!-- 1. CAPE ׻
     cape_c=CAPE( pres, height, qv, temp, z_ref, undef )

!-- 2. CIN ׻
     cin_c=CIN( pres, height, qv, temp, z_ref, undef )

!-- 3. Ĺ߿̷׻
     precip=precip_water( pres, qv, undef )

!-- 4. LCL ٷ׻
     height_lcl=z_LCL( z_ref, height, temp, pres, qv )
     call interpo_search_1d( height, height_lcl, iz, int(undef) )
     if(iz/=int(undef))then
        call interpolation_1d( height(iz:iz+1), pres(iz:iz+1),  &
  &                            height_lcl, pres_lcl )
     else
        pres_lcl=undef
     end if

!-- 5. LFC ٷ׻
     height_lfc=z_LFC( z_ref, height, temp, pres, qv )
     call interpo_search_1d( height, height_lfc, iz, int(undef) )
     if(iz/=int(undef))then
        call interpolation_1d( height(iz:iz+1), pres(iz:iz+1),  &
  &                            height_lfc, pres_lfc )
     else
        pres_lfc=undef
     end if

!-- 6. LNB ٷ׻
     height_lnb=z_LNB( z_ref, height, temp, pres, qv )
     call interpo_search_1d( height, height_lnb, iz, int(undef) )
     if(iz/=int(undef))then
        call interpolation_1d( height(iz:iz+1), pres(iz:iz+1),  &
  &                            height_lnb, pres_lnb )
     else
        pres_lnb=undef
     end if

!-- 7. ⤷, ʬ¾Υѥ᡼׻ǽ.

!-- 8. data -> array

     write_data(i,1)=z_ref
     write_data(i,2)=p_ref
     write_data(i,3)=cape_c
     write_data(i,4)=cin_c
     write_data(i,5)=precip
     write_data(i,6)=height_lcl
     write_data(i,7)=height_lfc
     write_data(i,8)=height_lnb
     write_data(i,9)=pres_lcl
     write_data(i,10)=pres_lfc
     write_data(i,11)=pres_lnb

!-- ʬۺʬ
     if(draw_flag(1:1)/='x')then
        do j=1,nz
           if(temp(j)/=undef.and.qv(j)/=undef.and.pres(j)/=undef)then
              pt(j)=theta_dry( temp(j), pres(j) )
              ept(j)=thetae_Bolton( temp(j), qv(j), pres(j) )
              sept(j)=thetaes_Bolton( temp(j), pres(j) )
           else
              pt(j)=undef
              ept(j)=undef
              sept(j)=undef
           end if
           do k=1,3
              draw_tate(j,k)=height(j)
           end do
           draw_yoko(j,1)=pt(j)
           draw_yoko(j,2)=ept(j)
           draw_yoko(j,3)=sept(j)
        end do
     end if

!-- skew-T ץåȺʬ

     call SGLSET('LCLIP',.true.)

     if(draw_flag(1:1)=='o')then
        call Dcl_PL( 'l', trim(fname(2,i)), draw_yoko, draw_tate,  &
  &                  draw_yoko, draw_tate, (/'Kelvin', 'height'/),  &
  &                  x_int=(/280.0, 380.0/), y_int=(/0.0, 2.0e4/),  &
  &                  viewx_int=(/0.3, 0.7/), viewy_int=(/0.2, 0.8/) )
        if(draw_flag(4:4)=='o')then
           call Dcl_Square_Normal( convx(1:2), convy(1:2), 12, 999999 )
           do j=1,jmax
              if(trim(title_u(j))=='hPa'.and.write_data(i,j)/=undef)then
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j)*1.0e-2, '(f8.1)' )
              else
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j), '(f8.1)' )
              end if
              skew_c=trim(skew_c)//trim(title_u(j))
              call DclDrawTextNormalized( cvx(j,1), cvy(j,1), trim(skew_c),  &
  &                                    height=0.0125, centering=-1 )
           end do
        end if
     end if

     if(draw_flag(2:2)=='o')then
        call SkewT( trim(fname(2,i)), 20.0, (/240.0, 300.0/),  &
  &                 draw_region_p, temp, pres, qv,  &
  &                 undef=-999.0 )
        if(draw_flag(4:4)=='o')then
           call Dcl_Square_Normal( convx(3:4), convy(3:4), 12, 999999 )
           do j=1,jmax
              if(trim(title_u(j))=='hPa'.and.write_data(i,j)/=undef)then
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j)*1.0e-2, '(f8.1)' )
              else
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j), '(f8.1)' )
              end if
              skew_c=trim(skew_c)//trim(title_u(j))
              call DclDrawTextNormalized( cvx(j,2), cvy(j,2), trim(skew_c),  &
  &                                    height=0.0125, centering=-1 )
           end do
        end if
     end if

     if(draw_flag(3:3)=='o')then
        call SkewT_vec( trim(fname(2,i)), 20.0, (/240.0, 300.0/),  &
  &                     draw_region_p, temp, pres, qv, ew, ww,  &
  &                     undef=-999.0 )
        if(draw_flag(4:4)=='o')then
           call Dcl_Square_Normal( convx(5:6), convy(5:6), 12, 999999 )
           do j=1,jmax
              if(trim(title_u(j))=='hPa'.and.write_data(i,j)/=undef)then
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j)*1.0e-2, '(f8.1)' )
              else
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j), '(f8.1)' )
              end if
              skew_c=trim(skew_c)//trim(title_u(j))
              call DclDrawTextNormalized( cvx(j,3), cvy(j,3), trim(skew_c),  &
  &                                    height=0.0125, centering=-1 )
           end do
        end if
     end if


     deallocate(cval)
     deallocate(height)
     deallocate(temp)
     deallocate(pres)
     deallocate(qv)
     deallocate(ew)
     deallocate(ww)
     deallocate(tmp)
     deallocate(pt)
     deallocate(ept)
     deallocate(sept)
     deallocate(draw_tate)
     deallocate(draw_yoko)

  end if
  end do

!-- 10. Ƽѥ᡼Υƥȥǡ¸

  if(dmp_flag.eqv..true.)then  ! ήѥ᡼ƥȥǡȤ¸.

     open(unit=10,file='convec_parm'//trim(list_name),status='unknown')
     tmp_char="'data-name' "//"'reference-height' "//"'CAPE' "//  &
  &                   "'CIN' "//"'precipitable-water' "//  &
  &                   "'LCL-height' "//"'LFC-height' "//"'LNB-height' "//  &
  &                   "'LCL-pressure' "//"'LFC-pressure' "//"'LNB-pressure' "
     t_c=i2c_convert( len_trim(tmp_char) )
     write(10,'(a'//trim(t_c)//')') trim(tmp_char)
     tmp_char=''
     t_c=''
     tmp_char="'character' "//"'m' "//"'J/kg' "//  &
  &                   "'J/kg' "//"'mm' "//"'m' "//"'m' "//"'m' "//  &
  &                   "'Pa' "//"'Pa' "//"'Pa' " 
     t_c=i2c_convert( len_trim(tmp_char) )
write(*,*) '(a'//trim(t_c)//')', t_c, len_trim(tmp_char)
     write(10,'(a'//trim(t_c)//')') trim(tmp_char)

     do i=1,nnz
!        write(10,'(a20,1000f)') trim(fname(2,i)), (write_data(i,j),j=1,jmax)
        write(10,*) trim(fname(2,i)), (write_data(i,j),j=1,jmax)
!     write(10,'(a20,1000f)') trim(fname(2,i)), z_ref, p_ref, cape_c, cin_c,  &
!     write(10,'(a20,1000f)') trim(fname(2,i)), z_ref, p_ref, cape_c,  &
!     write(10,*) trim(fname(2,i)), z_ref, p_ref, cape_c,  &
!  &                           precip, height_lcl, height_lfc, height_lnb,  &
!  &                           pres_lcl, pres_lfc, pres_lnb
     end do

     write(*,*) "CLOSED"

     close(unit=10,status='keep')

  end if

  call DclCloseGraphics

end program

==> libstpk-0.9.6.0.tar.gz: libstpk-0.9.6.0/demo/sound_analysis/sound_1d.f90 <==
program sound_1d
! 饸ιصݴ¬ǡ, 1 Υץեǡ
! , ٤ˤѡˤ CAPE Υѥ᡼׻.
! ǥǡΥեޥåȤϥƥȷΤߥݡ

  use Thermo_Const
  use Thermo_Function
  use Thermo_Advanced_Function
  use file_operate
  use Statistics
  use Basis
  use dcl
  use Dcl_Automatic
  use Dcl_Thermo_Graph

  implicit none

  real, allocatable, dimension(:) :: temp    ! 
  real, allocatable, dimension(:) :: height  ! 
  real, allocatable, dimension(:) :: pres    ! 
  real, allocatable, dimension(:) :: rh      ! м
  real, allocatable, dimension(:) :: qv      ! 
  real, allocatable, dimension(:) :: pt      ! 
  real, allocatable, dimension(:) :: ept     ! 
  real, allocatable, dimension(:) :: sept    ! ˰
  real, allocatable, dimension(:) :: ew      ! 
  real, allocatable, dimension(:) :: ww      ! 
  real, allocatable, dimension(:) :: tmp     ! ƥݥ
  real, allocatable, dimension(:,:) :: draw_tate, draw_yoko, write_data
  real :: height_lcl, pres_lcl  ! LCL 
  real :: height_lfc, pres_lfc  ! LFC 
  real :: height_lnb, pres_lnb  ! LNB 
  real :: cape_c  ! CAPE
  real :: cin_c  ! CIN
  real :: precip  ! Ĺ߿
  real :: z_ref  ! CAPE η׻κ, .
  real :: p_ref  ! CAPE η׻κ, ൤.
  real, dimension(2) :: draw_region_p, draw_region_z
  real, dimension(6), parameter :: convx=(/0.3, 0.5, 0.55, 0.75, 0.55, 0.75/),  &
                                   convy=(/0.5, 0.8, 0.5, 0.8, 0.5, 0.8/)
  real, allocatable, dimension(:,:) :: cvx, cvy

  integer :: i, j, k, l, m, n, iz, jmax
  integer :: nz  ! 
  integer :: nnz  ! ǡޤȤ˻Ȥΰˤ
  integer :: nx  ! ǡο
  integer :: IWS
  integer, parameter :: fig_num=3  ! ޤμ

  character(80), allocatable, dimension(:,:) :: fname  ! ǡե̾
  character(80) :: list_name  ! ǡꥹȥե̾
  character(20), allocatable, dimension(:,:) :: cval  ! ǡɤ߹
  character(1000) :: tmp_char
  character(4) :: draw_flag  ! ޤ˴ؤե饰
  character(10) :: t_c
  character(28) :: skew_c
  character(10), allocatable, dimension(:) :: title_c, title_u
  character(1) :: refer_flag

  logical :: dmp_flag

  real :: undef
  integer, parameter :: skip_num=2

!-- namelist file ɤ߹

  namelist /input /z_ref, p_ref, list_name, dmp_flag, undef, draw_flag,  &
  &                draw_region_p, draw_region_z, IWS, refer_flag
  read(5,nml=input)

  if(z_ref==-999.0)then
     refer_flag='p'
  end if

  if(p_ref==-999.0)then
     refer_flag='z'
  end if

  jmax=11

  allocate(title_c(jmax))
  allocate(title_u(jmax))
  allocate(cvx(jmax,fig_num))
  allocate(cvy(jmax,fig_num))

  title_c=(/'z_ref"', 'p_ref"', 'CAPE  ', 'CIN   ', 'PW    ', 'z_LCL"',  &
  &         'z_LFC"', 'z_LNB"', 'p_LCL"', 'p_LFC"', 'p_LNB"'/)
  title_u=(/' m       ', ' hPa     ', ' J kg|-1"', ' J kg|-1"',  &
  &         ' mm      ', ' m       ',   &
  &         ' m       ', ' m       ', ' hPa     ', ' hPa     ', ' hPa     '/)

  do i=1,fig_num
     cvx(:,i)=convx((i-1)*2+1)+0.01
     do j=1,jmax
        cvy(j,i)=convy(2*i)-0.01-(convy(2*i)-convy(2*(i-1)+1)-0.02)  &
  &              *real(j-1)/real(jmax-1)
     end do
  end do

!-- ɤ߹ǡեο
  nnz=line_number_counter( trim(list_name) )

  allocate(fname(2,nnz))
  allocate(write_data(nnz,jmax))

!-- DCL set
  call DclOpenGraphics(IWS)

  call GLRSET('RMISS',undef)
  call GLLSET('LMISS',.true.)
  call UZFACT( 0.6 )
  call DclSetParm('ENABLE_PROPORTIONAL_FONT',.true.)

  call read_file_text( trim(list_name), 2, nnz, fname )
  
  do i=1,nnz

  if(trim(fname(1,i))/='unknown')then
!-- ƥȥեɤ߹

     nz=line_number_counter( trim(fname(1,i)) )-skip_num  ! ƥȥñ̤ʬð

!-- 

     allocate(cval(6,nz))
     allocate(height(nz))
     allocate(temp(nz))
     allocate(pres(nz))
     allocate(qv(nz))
     allocate(ew(nz))
     allocate(ww(nz))
     allocate(tmp(nz))
     allocate(pt(nz))
     allocate(ept(nz))
     allocate(sept(nz))
     allocate(draw_tate(nz,3))
     allocate(draw_yoko(nz,3))

!-- ե뤫ǡɤ߹
     call read_file_text( trim(fname(1,i)), 6, nz, cval, skip=skip_num )
     write(*,*) "reading file ", trim(fname(1,i))

!-- character -> real
     do j=1,nz
        height(j)=c2r_convert( cval(1,j) )
        pres(j)=c2r_convert( cval(2,j) )
        temp(j)=c2r_convert( cval(3,j) )
        qv(j)=c2r_convert( cval(4,j) )
        ew(j)=c2r_convert( cval(5,j) )
        ww(j)=c2r_convert( cval(6,j) )
     end do

!-- z_ref  p_ref ֤
     if(refer_flag=='p')then
        ! interpo 뤿󲽽
        do j=1,nz
           tmp(j)=pres(nz-j+1)
        end do
        call interpo_search_1d( tmp, p_ref, iz )
        call interpolation_1d( tmp(iz:iz+1), (/height(nz-iz+1),height(nz-iz)/),  &
  &                             p_ref, z_ref )
     end if

!-- p_ref  z_ref ֤
     if(refer_flag=='z')then
        ! interpo 뤿󲽽
        do j=1,nz
           tmp(j)=pres(nz-j+1)
        end do
        call interpo_search_1d( height, z_ref, iz )
        call interpolation_1d( height(iz:iz+1), (/tmp(nz-iz+1), tmp(nz-iz)/),  &
  &                             z_ref, p_ref )
     end if

!-- z_ref  p_ref ֤
!  ν¿ʬʤ.
!     if(z_ref==-999.0)then
        ! interpo 뤿󲽽
!        call interpo_search_1d( height, z_ref, iz )
!        call interpolation_1d( height(iz:iz+1), pres(iz:iz+1),  &
!  &                             z_ref, p_ref )
!     end if

!-- ή԰ѥ᡼׻
!-- 1. CAPE ׻
     cape_c=CAPE( pres, height, qv, temp, z_ref, undef )

!-- 2. CIN ׻
     cin_c=CIN( pres, height, qv, temp, z_ref, undef )

!-- 3. Ĺ߿̷׻
     precip=precip_water( pres, qv, undef )

!-- 4. LCL ٷ׻
     height_lcl=z_LCL( z_ref, height, temp, pres, qv )
     call interpo_search_1d( height, height_lcl, iz, int(undef) )
     if(iz/=int(undef))then
        call interpolation_1d( height(iz:iz+1), pres(iz:iz+1),  &
  &                            height_lcl, pres_lcl )
     else
        pres_lcl=undef
     end if

!-- 5. LFC ٷ׻
     height_lfc=z_LFC( z_ref, height, temp, pres, qv )
     call interpo_search_1d( height, height_lfc, iz, int(undef) )
     if(iz/=int(undef))then
        call interpolation_1d( height(iz:iz+1), pres(iz:iz+1),  &
  &                            height_lfc, pres_lfc )
     else
        pres_lfc=undef
     end if

!-- 6. LNB ٷ׻
     height_lnb=z_LNB( z_ref, height, temp, pres, qv )
     call interpo_search_1d( height, height_lnb, iz, int(undef) )
     if(iz/=int(undef))then
        call interpolation_1d( height(iz:iz+1), pres(iz:iz+1),  &
  &                            height_lnb, pres_lnb )
     else
        pres_lnb=undef
     end if

!-- 7. ⤷, ʬ¾Υѥ᡼׻ǽ.

!-- 8. data -> array

     write_data(i,1)=z_ref
     write_data(i,2)=p_ref
     write_data(i,3)=cape_c
     write_data(i,4)=cin_c
     write_data(i,5)=precip
     write_data(i,6)=height_lcl
     write_data(i,7)=height_lfc
     write_data(i,8)=height_lnb
     write_data(i,9)=pres_lcl
     write_data(i,10)=pres_lfc
     write_data(i,11)=pres_lnb

!-- ʬۺʬ
     if(draw_flag(1:1)/='x')then
        do j=1,nz
           if(temp(j)/=undef.and.qv(j)/=undef.and.pres(j)/=undef)then
              pt(j)=theta_dry( temp(j), pres(j) )
              ept(j)=thetae_Bolton( temp(j), qv(j), pres(j) )
              sept(j)=thetaes_Bolton( temp(j), pres(j) )
           else
              pt(j)=undef
              ept(j)=undef
              sept(j)=undef
           end if
           do k=1,3
              draw_tate(j,k)=height(j)
           end do
           draw_yoko(j,1)=pt(j)
           draw_yoko(j,2)=ept(j)
           draw_yoko(j,3)=sept(j)
        end do
     end if

!-- skew-T ץåȺʬ

     call SGLSET('LCLIP',.true.)

     if(draw_flag(1:1)=='o')then
        call Dcl_PL( 'l', trim(fname(2,i)), draw_yoko, draw_tate,  &
  &                  draw_yoko, draw_tate,  &
  &                  (/achar(241)//'(pink), '//achar(241)//'_e"(blue), '//  &
  &                    achar(241)//'_es"(orange)  (K)', 'height (m)'/),  &
  &                  x_int=(/280.0, 380.0/), y_int=(/0.0, 2.0e4/),  &
  &                  viewx_int=(/0.3, 0.7/), viewy_int=(/0.2, 0.8/) )
        if(draw_flag(4:4)=='o')then
           call Dcl_Square_Normal( convx(1:2), convy(1:2), 12, 999999 )
           do j=1,jmax
              if(trim(adjustl(title_u(j)))=='hPa'.and.write_data(i,j)/=undef)then
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j)*1.0e-2, '(f8.1)' )
              else
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j), '(f8.1)' )
              end if
              skew_c=trim(skew_c)//trim(title_u(j))
              call DclDrawTextNormalized( cvx(j,1), cvy(j,1), trim(skew_c),  &
  &                                    height=0.0125, centering=-1 )
           end do
        end if
     end if

     if(draw_flag(2:2)=='o')then
        call SkewT( trim(fname(2,i)), 20.0, (/240.0, 300.0/),  &
  &                 draw_region_p, temp, pres, qv,  &
  &                 undef=-999.0 )
        if(draw_flag(4:4)=='o')then
           call Dcl_Square_Normal( convx(3:4), convy(3:4), 12, 999999 )
           do j=1,jmax
              if(trim(adjustl(title_u(j)))=='hPa'.and.write_data(i,j)/=undef)then
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j)*1.0e-2, '(f8.1)' )
              else
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j), '(f8.1)' )
              end if
              skew_c=trim(skew_c)//trim(title_u(j))
              call DclDrawTextNormalized( cvx(j,2), cvy(j,2), trim(skew_c),  &
  &                                    height=0.0125, centering=-1 )
           end do
        end if
     end if

     if(draw_flag(3:3)=='o')then
        call SkewT_vec( trim(fname(2,i)), 20.0, (/240.0, 300.0/),  &
  &                     draw_region_p, temp, pres, qv, ew, ww,  &
  &                     undef=-999.0 )
        if(draw_flag(4:4)=='o')then
           call Dcl_Square_Normal( convx(5:6), convy(5:6), 12, 999999 )
           do j=1,jmax
              if(trim(adjustl(title_u(j)))=='hPa'.and.write_data(i,j)/=undef)then
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j)*1.0e-2, '(f8.1)' )
              else
                 skew_c=trim(title_c(j))//r2c_convert( write_data(i,j), '(f8.1)' )
              end if
              skew_c=trim(skew_c)//trim(title_u(j))
              call DclDrawTextNormalized( cvx(j,3), cvy(j,3), trim(skew_c),  &
  &                                    height=0.0125, centering=-1 )
           end do
        end if
     end if


     deallocate(cval)
     deallocate(height)
     deallocate(temp)
     deallocate(pres)
     deallocate(qv)
     deallocate(ew)
     deallocate(ww)
     deallocate(tmp)
     deallocate(pt)
     deallocate(ept)
     deallocate(sept)
     deallocate(draw_tate)
     deallocate(draw_yoko)

  else
     do j=1,jmax
        write_data(i,j)=undef
     end do
  end if
  end do

!-- 10. Ƽѥ᡼Υƥȥǡ¸

  if(dmp_flag.eqv..true.)then  ! ήѥ᡼ƥȥǡȤ¸.

     open(unit=10,file='convec_parm'//trim(list_name),status='unknown')
     tmp_char="'data name' "//"'reference height' "//"'reference pressure' "  &
  &                   //"'CAPE' "//  &
  &                   "'CIN' "//"'precipitable water' "//  &
  &                   "'LCL height' "//"'LFC height' "//"'LNB height' "//  &
  &                   "'LCL pressure' "//"'LFC pressure' "//"'LNB pressure' "
     t_c=trim( adjustl(i2c_convert( len_trim(tmp_char) )) )
     write(10,'(a'//trim(t_c)//')') trim(tmp_char)
     tmp_char=''
     t_c=''
     tmp_char="'character' "//"'m' "//"'Pa' "//"'"//'J kg|-1"'//"' "//  &
  &                   "'"//'J kg|-1"'//"' "//"'mm' "//"'m' "//"'m' "//  &
  &                   "'m' "//"'Pa' "//"'Pa' "//"'Pa' " 
     t_c=trim( adjustl( i2c_convert( len_trim(tmp_char) ) ) )
     write(10,'(a'//trim(t_c)//')') trim(tmp_char)

     tmp_char='('
     t_c=''

     tmp_char='(a20,'//trim( adjustl( i2c_convert( jmax ) ) )//'f)'
write(*,*) "format", trim(tmp_char)

     do i=1,nnz
!        write(10,'(a20,1000f)') trim(fname(2,i)), (write_data(i,j),j=1,jmax)
        write(10,trim(tmp_char)) trim( adjustl( fname(2,i) ) ),  &
  &                              (write_data(i,j),j=1,jmax)
!     write(10,'(a20,1000f)') trim(fname(2,i)), z_ref, p_ref, cape_c, cin_c,  &
!     write(10,'(a20,1000f)') trim(fname(2,i)), z_ref, p_ref, cape_c,  &
!     write(10,*) trim(fname(2,i)), z_ref, p_ref, cape_c,  &
!  &                           precip, height_lcl, height_lfc, height_lnb,  &
!  &                           pres_lcl, pres_lfc, pres_lnb
     end do

     write(*,*) "CLOSED"

     close(unit=10,status='keep')

  end if

  call DclCloseGraphics

end program
